@@ -4,14 +4,12 @@ from pynhost import dynamic
 OPENING_TOKEN_DICT = {
     '(': 'list',
     '[': 'optional',
-    '{': 'dict',
     '<': 'special',
 }
 
 CLOSING_TOKEN_DICT = {
     ')': 'list',
     ']': 'optional',
-    '}': 'dict',
     '>': 'special',
 }
 
@@ -25,14 +23,13 @@ class RulePiece:
         return '<RulePiece {}>'.format(self.mode)
 
 class Rule:
-    def __init__(self, raw_text, dictionary=None, actions=None, grammar=None):
+    def __init__(self, raw_text, actions=None, grammar=None):
         if not isinstance(actions, list):
             actions = [actions]
         self.actions = actions
         self.raw_text = raw_text
         self.pieces = parse(raw_text)
         self.grammar = grammar
-        self.dictionary = dictionary
 
     def __str__(self):
         return '<Rule: {}>'.format(self.raw_text)
@@ -47,7 +44,7 @@ def parse(rule_string):
     for i, char in enumerate(rule_string.strip()):
         if char == ' ':
             continue
-        if char in '([{<':
+        if char in '([<':
             if piece_stack and piece_stack[-1].mode == 'special':
                 raise ValueError('parsing error at char {}'.format(i))
             mode = OPENING_TOKEN_DICT[char]
@@ -56,7 +53,7 @@ def parse(rule_string):
                 pieces.append(piece_stack[0])
             else:
                 piece_stack[-2].children.append(piece_stack[-1])
-        elif char in ')]}>':
+        elif char in ')]>':
             if not piece_stack or CLOSING_TOKEN_DICT[char] != piece_stack[-1].mode:
                 raise ValueError('error balancing tokens at {}'.format(i))
             piece_stack.pop()
@@ -65,8 +62,6 @@ def parse(rule_string):
             else:
                 mode = 'normal'
         else:
-            if mode == 'dict':
-                raise RuntimeError('dictionaries in rule must be empty')
             if mode == 'list':
                 if char == '|':
                     piece_stack[-1].children.append(OrToken())
